@@ -20,7 +20,7 @@
   * External interface.
   */
 extern int defer_append(int, const char *, MSG_STATS *, RECIPIENT *,
-			        const char *, const TLS_STATS *, DSN *);
+			        const char *, const POL_STATS *, DSN *);
 extern int defer_flush(int, const char *, const char *, const char *, int,
 		               const char *, const char *, int);
 extern int defer_warn(int, const char *, const char *, const char *, int,
@@ -28,7 +28,7 @@ extern int defer_warn(int, const char *, const char *, const char *, int,
 extern int defer_one(int, const char *, const char *, const char *, int,
 		             const char *, const char *,
 		             int, MSG_STATS *, RECIPIENT *,
-		             const char *, const TLS_STATS *, DSN *);
+		             const char *, const POL_STATS *, DSN *);
 
  /*
   * Start of private API.
@@ -36,7 +36,7 @@ extern int defer_one(int, const char *, const char *, const char *, int,
 #ifdef DSN_INTERN
 
 extern int defer_append_intern(int, const char *, MSG_STATS *, RECIPIENT *,
-			            const char *, const TLS_STATS *, DSN *);
+			            const char *, const POL_STATS *, DSN *);
 
 #endif
 
