@@ -261,19 +261,19 @@ typedef struct SMTP_STATE {
 
 #define smtp_tls_stat_activate_sec_level(tstats, level) \
 	pol_stat_activate((tstats), SMTP_TLS_STAT_IDX_SEC_LEVEL, \
-	    str_tls_level(level), POL_STAT_ENF_FULL)
+	    str_tls_level(level))
 
 #define smtp_tls_stat_activate_sec_unknown(tstats) \
 	pol_stat_activate((tstats), SMTP_TLS_STAT_IDX_SEC_LEVEL, \
-	    SMTP_TLS_STAT_NAME_UNKNOWN, POL_STAT_ENF_FULL)
+	    SMTP_TLS_STAT_NAME_UNKNOWN)
 
 #define smtp_tls_stat_decide_sec_level(tstats, level, status) \
 	pol_stat_decide((tstats), SMTP_TLS_STAT_IDX_SEC_LEVEL, \
 	    str_tls_level(level), (status))
 
-#define smtp_tls_stat_activate_reqtls(tstats, name, enforce) \
+#define smtp_tls_stat_activate_reqtls(tstats, name) \
 	pol_stat_activate((tstats), SMTP_TLS_STAT_IDX_REQTLS, \
-	(name), (enforce))
+	(name))
 
 #define smtp_tls_stat_decide_reqtls(tstats, name, status) \
 	pol_stat_decide((tstats), SMTP_TLS_STAT_IDX_REQTLS, \
