@@ -175,14 +175,14 @@ static int regexp_table_no_error(const TEST_CASE *tp)
     return (errors == 0);
 }
 
-static int default_is_best_effort(const TEST_CASE *tp)
+static int default_is_enforce(const TEST_CASE *tp)
 {
-    const char *ext_policy = "regexp:{{/^foo\\.example$/ enforce}}";
+    const char *ext_policy = "regexp:{{/^foo\\.example$/ opportunistic+starttls}}";
     const struct QUERY_REPLY qr[] = {
-	{"foo.example", SMTP_REQTLS_POLICY_ACT_ENFORCE},
-	{"x.foo.example", SMTP_REQTLS_POLICY_ACT_OPP_TLS},
-	{"bar.example", SMTP_REQTLS_POLICY_ACT_OPP_TLS},
-	{"other", SMTP_REQTLS_POLICY_ACT_OPP_TLS},
+	{"foo.example", SMTP_REQTLS_POLICY_ACT_OPP_TLS},
+	{"x.foo.example", SMTP_REQTLS_POLICY_ACT_ENFORCE},
+	{"bar.example", SMTP_REQTLS_POLICY_ACT_ENFORCE},
+	{"other", SMTP_REQTLS_POLICY_ACT_ENFORCE},
 	{0},
     };
     SMTP_REQTLS_POLICY *int_policy;
@@ -208,7 +208,7 @@ static int disallow_nested_table(const TEST_CASE *tp)
     const char *ext_policy = "inline:{{foo.example = hash:/no/where}}";
     const struct QUERY_REPLY qr[] = {
 	{"foo.example", SMTP_REQTLS_POLICY_ACT_ERROR},
-	{"x.foo.example", SMTP_REQTLS_POLICY_ACT_OPP_TLS},
+	{"x.foo.example", SMTP_REQTLS_POLICY_ACT_ENFORCE},
 	{0},
     };
     SMTP_REQTLS_POLICY *int_policy;
@@ -235,7 +235,7 @@ static TEST_CASE test_cases[] = {
     "non_regexp_policy_error_at_start", non_regexp_policy_error_at_start,
     "policy_table_lookup_error", policy_table_lookup_error,
     "regexp_table_no_error", regexp_table_no_error,
-    "default_is_best_effort", default_is_best_effort,
+    "default_is_enforce", default_is_enforce,
     "disallow_nested_table", disallow_nested_table,
     0,
 };
