@@ -28,28 +28,26 @@ extern ARGV *argv_qsort(ARGV *, ARGV_COMPAR_FN);
 extern ARGV *argv_uniq(ARGV *, ARGV_COMPAR_FN);
 extern void argv_add(ARGV *,...);
 extern void argv_addn(ARGV *,...);
+extern ARGV *argv_addv(ARGV *, const char *const *);
 extern void argv_terminate(ARGV *);
 extern void argv_truncate(ARGV *, ssize_t);
 extern void argv_insert_one(ARGV *, ssize_t, const char *);
 extern void argv_replace_one(ARGV *, ssize_t, const char *);
 extern void argv_delete(ARGV *, ssize_t, ssize_t);
+struct VSTRING;
+extern char *argv_join(struct VSTRING *buf, ARGV *, int);
 extern ARGV *argv_free(ARGV *);
 
 extern ARGV *argv_split(const char *, const char *);
-extern ARGV *argv_split_cw(const char *, const char *, const char *);
+extern ARGV *argv_split_count(const char *, const char *, ssize_t);
 extern ARGV *argv_split_append(ARGV *, const char *, const char *);
-extern ARGV *argv_split_append_cw(ARGV *, const char *, const char *, const char *);
-
-#define argv_split(cp, sp) argv_split_cw((cp), (sp), (char *) 0)
-#define argv_split_append(av, cp, sp) argv_split_append_cw((av), (cp), (sp), (char *) 0)
 
 extern ARGV *argv_splitq(const char *, const char *, const char *);
-extern ARGV *argv_splitq_cw(const char *, const char *, const char *, const char *);
+extern ARGV *argv_splitq_count(const char *, const char *, const char *, ssize_t);
 extern ARGV *argv_splitq_append(ARGV *, const char *, const char *, const char *);
 
-#define argv_splitq(cp, sp, pp) argv_splitq_cw((cp), (sp), (pp), (char *) 0)
-
 extern ARGV *argv_split_at(const char *, int);
+extern ARGV *argv_split_at_count(const char *, int, ssize_t);
 extern ARGV *argv_split_at_append(ARGV *, const char *, int);
 
 #define ARGV_FAKE_BEGIN(fake_argv, arg) { \
@@ -60,6 +58,15 @@ extern ARGV *argv_split_at_append(ARGV *, const char *, int);
 	fake_argv.argv = __fake_argv_args__; \
 	fake_argv.argc = fake_argv.len = 1;
 
+#define ARGV_FAKE2_BEGIN(fake_argv, arg1, arg2) { \
+	ARGV fake_argv; \
+	char *__fake_argv_args__[3]; \
+	__fake_argv_args__[0] = (char *) (arg1); \
+	__fake_argv_args__[1] = (char *) (arg2); \
+	__fake_argv_args__[2] = 0; \
+	fake_argv.argv = __fake_argv_args__; \
+	fake_argv.argc = fake_argv.len = 2;
+
 #define ARGV_FAKE_END	}
 
 #define ARGV_END	((char *) 0)
@@ -78,8 +85,6 @@ extern ARGV *argv_split_at_append(ARGV *, const char *, int);
 /*	Google, Inc.
 /*	111 8th Avenue
 /*	New York, NY 10011, USA
-/*
-/*	Wietse Venema
 /*--*/
 
 #endif
